<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs">
<context>
    <name>ViewToolBars</name>
    <message>
        <location filename="../ViewToolBarsPostInit.js" line="+6"/>
        <source>&amp;Toolbars and Widgets</source>
        <translation>Panely &amp;nástrojů a Widgety</translation>
    </message>
</context>
</TS>
